/*
 * Copyright [2022] [https://www.xiaonuo.vip]
 *
 * Snowy采用APACHE LICENSE 2.0开源协议，您在使用过程中，需要注意以下几点：
 *
 * 1.请不要删除和修改根目录下的LICENSE文件。
 * 2.请不要删除和修改Snowy源码头部的版权声明。
 * 3.本项目代码可免费商业使用，商业使用请保留源码和相关描述文件的项目出处，作者声明等。
 * 4.分发源码时候，请注明软件出处 https://www.xiaonuo.vip
 * 5.不可二次分发开源参与同类竞品，如有想法可联系团队xiaonuobase@qq.com商议合作。
 * 6.若您的项目无法满足以上几点，需要更多功能代码，获取Snowy商业授权许可，请在官网购买授权，地址为 https://www.xiaonuo.vip
 */
package vip.xiaonuo.modular.inventoryUse.service.impl;

import cn.hutool.core.bean.BeanUtil;
import cn.hutool.core.collection.CollStreamUtil;
import cn.hutool.core.util.ObjectUtil;
import cn.hutool.core.util.StrUtil;
import com.baomidou.mybatisplus.core.conditions.query.QueryWrapper;
import com.baomidou.mybatisplus.extension.plugins.pagination.Page;
import com.baomidou.mybatisplus.extension.service.impl.ServiceImpl;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;
import org.springframework.transaction.annotation.Transactional;
import org.springframework.web.multipart.MultipartFile;
import vip.xiaonuo.common.enums.CommonSortOrderEnum;
import vip.xiaonuo.common.exception.CommonException;
import vip.xiaonuo.common.page.CommonPageRequest;
import vip.xiaonuo.dev.modular.file.service.DevFileService;
import vip.xiaonuo.modular.inventoryUse.entity.InventoryUse;
import vip.xiaonuo.modular.inventoryUse.mapper.InventoryUseMapper;
import vip.xiaonuo.modular.inventoryUse.param.*;
import vip.xiaonuo.modular.inventoryUse.service.InventoryUseService;

import java.util.Date;
import java.util.List;

/**
 * 物资领用Service接口实现类
 *
 * @author newspaper
 * @date  2023/12/11 10:43
 **/
@Service
public class InventoryUseServiceImpl extends ServiceImpl<InventoryUseMapper, InventoryUse> implements InventoryUseService {

    @Autowired
    private DevFileService devFileService;

    @Override
    public Page<InventoryUse> page(InventoryUsePageParam inventoryUsePageParam) {
        QueryWrapper<InventoryUse> queryWrapper = new QueryWrapper<>();
        if(ObjectUtil.isNotEmpty(inventoryUsePageParam.getItemName())) {
            queryWrapper.lambda().like(InventoryUse::getItemName, inventoryUsePageParam.getItemName());
        }
        if(ObjectUtil.isAllNotEmpty(inventoryUsePageParam.getSortField(), inventoryUsePageParam.getSortOrder())) {
            CommonSortOrderEnum.validate(inventoryUsePageParam.getSortOrder());
            queryWrapper.orderBy(true, inventoryUsePageParam.getSortOrder().equals(CommonSortOrderEnum.ASC.getValue()),
                    StrUtil.toUnderlineCase(inventoryUsePageParam.getSortField()));
        } else {
            queryWrapper.lambda().orderByAsc(InventoryUse::getId);
        }
        return this.page(CommonPageRequest.defaultPage(), queryWrapper);
    }

    @Transactional(rollbackFor = Exception.class)
    @Override
    public void add(InventoryUseAddParam inventoryUseAddParam) {
        InventoryUse inventoryUse = BeanUtil.toBean(inventoryUseAddParam, InventoryUse.class);
        this.save(inventoryUse);
    }

    @Transactional(rollbackFor = Exception.class)
    @Override
    public void edit(InventoryUseEditParam inventoryUseEditParam) {
        InventoryUse inventoryUse = this.queryEntity(inventoryUseEditParam.getId());
        BeanUtil.copyProperties(inventoryUseEditParam, inventoryUse);
        this.updateById(inventoryUse);
    }

    @Transactional(rollbackFor = Exception.class)
    @Override
    public void delete(List<InventoryUseIdParam> inventoryUseIdParamList) {
        // 执行删除
        this.removeByIds(CollStreamUtil.toList(inventoryUseIdParamList, InventoryUseIdParam::getId));
    }

    @Override
    public InventoryUse detail(InventoryUseIdParam inventoryUseIdParam) {
        return this.queryEntity(inventoryUseIdParam.getId());
    }

    @Override
    public InventoryUse queryEntity(String id) {
        InventoryUse inventoryUse = this.getById(id);
        if(ObjectUtil.isEmpty(inventoryUse)) {
            throw new CommonException("物资领用不存在，id值为：{}", id);
        }
        return inventoryUse;
    }

    @Override
    public void revert(MultipartFile returnImgUrl, String id, Date returnTime, String remarks) {
        InventoryUse inventoryUse = this.getById(id);
        String url = devFileService.uploadReturnUrl("SNOWY_SYS_DEFAULT_FILE_ENGINE", returnImgUrl);
        inventoryUse.setReturnTime(returnTime);
        inventoryUse.setReturnImgUrl(url);
        inventoryUse.setRemarks(remarks);
        this.updateById(inventoryUse);


    }

}
