/*
 * Copyright [2022] [https://www.xiaonuo.vip]
 *
 * Snowy采用APACHE LICENSE 2.0开源协议，您在使用过程中，需要注意以下几点：
 *
 * 1.请不要删除和修改根目录下的LICENSE文件。
 * 2.请不要删除和修改Snowy源码头部的版权声明。
 * 3.本项目代码可免费商业使用，商业使用请保留源码和相关描述文件的项目出处，作者声明等。
 * 4.分发源码时候，请注明软件出处 https://www.xiaonuo.vip
 * 5.不可二次分发开源参与同类竞品，如有想法可联系团队xiaonuobase@qq.com商议合作。
 * 6.若您的项目无法满足以上几点，需要更多功能代码，获取Snowy商业授权许可，请在官网购买授权，地址为 https://www.xiaonuo.vip
 */
package vip.xiaonuo.modular.stage.controller;

import com.baomidou.mybatisplus.extension.plugins.pagination.Page;
import com.github.xiaoymin.knife4j.annotations.ApiOperationSupport;
import com.github.xiaoymin.knife4j.annotations.ApiSupport;
import io.swagger.annotations.Api;
import io.swagger.annotations.ApiOperation;
import org.springframework.validation.annotation.Validated;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RestController;
import vip.xiaonuo.common.annotation.CommonLog;
import vip.xiaonuo.common.pojo.CommonResult;
import vip.xiaonuo.common.pojo.CommonValidList;
import vip.xiaonuo.modular.stage.param.PigpenStageAddParam;
import vip.xiaonuo.modular.stage.param.PigpenStageEditParam;
import vip.xiaonuo.modular.stage.param.PigpenStageIdParam;
import vip.xiaonuo.modular.stage.param.PigpenStagePageParam;
import vip.xiaonuo.modular.stage.entity.PigpenStage;
import vip.xiaonuo.modular.stage.service.PigpenStageService;


import javax.annotation.Resource;
import javax.validation.Valid;
import javax.validation.constraints.NotEmpty;
import java.util.List;

/**
 * 栋舍阶段控制器
 *
 * @author newspaper
 * @date  2023/12/05 15:12
 */
@Api(tags = "栋舍阶段控制器")
@ApiSupport(author = "SNOWY_TEAM", order = 1)
@RestController
@Validated
public class PigpenStageController {

    @Resource
    private PigpenStageService pigpenStageService;

    /**
     * 获取栋舍阶段分页
     *
     * @author newspaper
     * @date  2023/12/05 15:12
     */
    @ApiOperationSupport(order = 1)
    @ApiOperation("获取栋舍阶段分页")
    @GetMapping("/biz/stage/page")
    public CommonResult<Page<PigpenStage>> page(PigpenStagePageParam pigpenStagePageParam) {
        return CommonResult.data(pigpenStageService.page(pigpenStagePageParam));
    }

    /**
     * 添加栋舍阶段
     *
     * @author newspaper
     * @date  2023/12/05 15:12
     */
    @ApiOperationSupport(order = 2)
    @ApiOperation("添加栋舍阶段")
    @CommonLog("添加栋舍阶段")
    @PostMapping("/biz/stage/add")
    public CommonResult<String> add(@RequestBody @Valid PigpenStageAddParam pigpenStageAddParam) {
        pigpenStageService.add(pigpenStageAddParam);
        return CommonResult.ok();
    }

    /**
     * 编辑栋舍阶段
     *
     * @author newspaper
     * @date  2023/12/05 15:12
     */
    @ApiOperationSupport(order = 3)
    @ApiOperation("编辑栋舍阶段")
    @CommonLog("编辑栋舍阶段")
    @PostMapping("/biz/stage/edit")
    public CommonResult<String> edit(@RequestBody @Valid PigpenStageEditParam pigpenStageEditParam) {
        pigpenStageService.edit(pigpenStageEditParam);
        return CommonResult.ok();
    }

    /**
     * 删除栋舍阶段
     *
     * @author newspaper
     * @date  2023/12/05 15:12
     */
    @ApiOperationSupport(order = 4)
    @ApiOperation("删除栋舍阶段")
    @CommonLog("删除栋舍阶段")
    @PostMapping("/biz/stage/delete")
    public CommonResult<String> delete(@RequestBody @Valid @NotEmpty(message = "集合不能为空")
                                                   CommonValidList<PigpenStageIdParam> pigpenStageIdParamList) {
        pigpenStageService.delete(pigpenStageIdParamList);
        return CommonResult.ok();
    }

    /**
     * 获取栋舍阶段详情
     *
     * @author newspaper
     * @date  2023/12/05 15:12
     */
    @ApiOperationSupport(order = 5)
    @ApiOperation("获取栋舍阶段详情")
    @GetMapping("/biz/stage/detail")
    public CommonResult<PigpenStage> detail(@Valid PigpenStageIdParam pigpenStageIdParam) {
        return CommonResult.data(pigpenStageService.detail(pigpenStageIdParam));
    }

    /**
     * 获取所有栋舍阶段
     *
     * @author newspaper
     * @date  2023/12/05 15:12
     */
    @ApiOperationSupport(order = 6)
    @ApiOperation("获取所有栋舍阶段")
    @GetMapping("/biz/stage/list")
    public CommonResult<List<PigpenStage>> list() {
        return CommonResult.data(pigpenStageService.getAllPigpenList());
    }
}
